# Change this to your own repo if you want to use a custom template(WARNING, COMPATABILITY IS NOT GUARANTEED):

TEMPLATE_REPO      = "https://github.com/robert19066/Example-Android-WV-App.git"  # this is the default template repo. Its privte(because i don't want people to think this is an ordinary template)
ASSETS_REL_PATH    = "app/src/main/assets"
# my honest recomandation is to keep TEMPLATE_REPO as it is.
# Also soon the template repo WILL be public so people can do their own templates.